CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
81 lines
2.0 KiB
C++
81 lines
2.0 KiB
C++
//===----------------------------------------------------------------------===//
|
|
//
|
|
// Part of libcu++, the C++ Standard Library for your entire system,
|
|
// under the Apache License v2.0 with LLVM Exceptions.
|
|
// See https://llvm.org/LICENSE.txt for license information.
|
|
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
|
// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
|
|
//
|
|
//===----------------------------------------------------------------------===//
|
|
|
|
#include "test_macros.h"
|
|
|
|
TEST_DIAG_SUPPRESS_MSVC(4505)
|
|
|
|
#include <cuda/annotated_ptr>
|
|
#include <cuda/std/cassert>
|
|
|
|
#include <nv/target>
|
|
|
|
#if defined(DEBUG)
|
|
# define DPRINTF(...) \
|
|
{ \
|
|
printf(__VA_ARGS__); \
|
|
}
|
|
#else
|
|
# define DPRINTF(...) \
|
|
do \
|
|
{ \
|
|
} while (false)
|
|
#endif
|
|
|
|
__device__ __host__ void assert_rt_wrap(cudaError_t code, const char* file, int line)
|
|
{
|
|
if (code != cudaSuccess)
|
|
{
|
|
#if !TEST_COMPILER(NVRTC)
|
|
NV_IF_ELSE_TARGET(NV_IS_HOST,
|
|
(printf("assert: %s %s %d\n", cudaGetErrorString(code), file, line);),
|
|
(printf("assert: error=%d %s %d\n", code, file, line);))
|
|
#endif // !TEST_COMPILER(NVRTC)
|
|
assert(code == cudaSuccess);
|
|
}
|
|
}
|
|
#define assert_rt(ret) \
|
|
{ \
|
|
assert_rt_wrap((ret), __FILE__, __LINE__); \
|
|
}
|
|
|
|
template <typename T, int N>
|
|
__device__ __host__ __noinline__ T* global_alloc()
|
|
{
|
|
T* arr = nullptr;
|
|
|
|
NV_IF_ELSE_TARGET(
|
|
NV_IS_DEVICE, (arr = (T*) malloc(N * sizeof(T));), (assert_rt(cudaMallocManaged((void**) &arr, N * sizeof(T)));))
|
|
|
|
for (int i = 0; i < N; ++i)
|
|
{
|
|
arr[i] = i;
|
|
}
|
|
return arr;
|
|
}
|
|
|
|
template <typename T, int N>
|
|
__device__ __noinline__ T* shared_alloc()
|
|
{
|
|
__shared__ T data[N];
|
|
|
|
for (int i = 0; i < N; ++i)
|
|
{
|
|
data[i] = i;
|
|
}
|
|
return data;
|
|
}
|
|
|
|
template <typename T>
|
|
__device__ __host__ __noinline__ void dealloc(T* arr)
|
|
{
|
|
NV_IF_ELSE_TARGET(NV_IS_DEVICE, (free(arr);), assert_rt(cudaFree(arr));)
|
|
}
|